@@ -1,7 +1,4 @@
 #######################################################################
-# $Date$
-# $Revision$
-# $Author$
 # ex: set ts=8 sw=4 et
 #########################################################################
 package WWW::Facebook::API::Notifications;
@@ -10,11 +7,11 @@ use warnings;
 use strict;
 use Carp;
 
-use version; our $VERSION = qv('0.4.14');
-
 sub get  { return shift->base->call( 'notifications.get',  @_ ) }
 sub send { return shift->base->call( 'notifications.send', @_ ) } ## no critic
 sub send_email { return shift->base->call( 'notifications.sendEmail', @_ ); }
+sub get_list { return shift->base->call( 'notifications.getList', @_ ); }
+sub mark_read { return shift->base->call( 'notifications.markRead', @_ ); }
 
 1;    # Magic true value required at end of module
 __END__
@@ -23,10 +20,6 @@ __END__
 
 WWW::Facebook::API::Notifications - Facebook Notifications
 
-=head1 VERSION
-
-This document describes WWW::Facebook::API::Notifications version 0.4.14
-
 =head1 SYNOPSIS
 
     use WWW::Facebook::API;
@@ -73,6 +66,20 @@ The notifications.sendEmail method of the Facebook API:
         fbml  => 'fbml version of email body',
     );
 
+=item get_list( %params )
+
+The notifications.getList method of the Facebook API:
+
+    $response = $client->notifications->get_list();
+
+=item mark_read( %params )
+
+The notifications.markRead method of the Facebook API:
+
+    $response = $client->notifications->mark_read(
+        notification_ids => [@notification_ids],
+    );
+
 =back
 
 =head1 DIAGNOSTICS
